Dark mode playground - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Dark mode playground

Lorem ipsum dolor sit amet, consectetur adipisicing elit. Alias magni minus omnis provident qui repudiandae saepe sunt vel, veniam voluptatibus? Cum eius est harum molestias necessitatibus quasi repellat velit voluptatum.

Default
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Default
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan

Lorem ipsum dolor sit amet, consectetur adipisicing elit. Alias magni minus omnis provident qui repudiandae saepe sunt vel, veniam voluptatibus? Cum eius est harum molestias necessitatibus quasi repellat velit voluptatum.

Default
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Default
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan